@@ -27,5 +27,5 @@ DEFAULT_JWT_AUTHORIZATION_HEADER_NAME = "Authorization"
 DEFAULT_JWT_AUTHORIZATION_HEADER_TYPE = "Bearer"
 
 DEFAULT_JWT_SESSION_ALGORITHM = "HS256" ###- HS512
-DEFAULT_JWT_SESSION_HEADER_NAME = "Session-Context"
+DEFAULT_JWT_SESSION_HEADER_NAME = "Context"
 DEFAULT_JWT_SESSION_HEADER_TYPE = "Bearer"
